@@ -7,8 +7,12 @@ from struct import pack
 from mc_connection import mc
 
 def _mc_get_multi(self, args_list):
-    result = self.get_list(args_list)
-    return dict(zip(args_list, result))
+    if not isinstance(args_list, (list, tuple, dict, set)):
+        args_list = tuple(args_list)
+    if args_list:
+        result = self.get_list(args_list)
+        return dict(zip(args_list, result))
+    return {}
 
 def _mc_decorator(self, key, expire=0):
     if type(key) is str:
@@ -51,7 +55,7 @@ def _mc_delete(self, *args):
 class McCacheM(object):
     def __init__(self, key_pattern):
         self.key_pattern = key_pattern
-    
+
     def get(self, *args):
         key = self.key_pattern%args
         return mc.get_marshal(key)
@@ -120,35 +124,99 @@ class McCache(object):
 
 
 class McCacheA(object):
-    def __init__(self, key_pattern,type='L'):
+    def __init__(self, key_pattern, type='L'):
         self.key_pattern = key_pattern
         self.type = type
 
     def get(self, *args):
         key = self.key_pattern%args
-        result =  mc.get(key)
+        result = mc.get(key)
         if result is not None:
-            return array(self.type,result)
+            return array(self.type, result)
 
     def set(self, key, value, expire=0):
         key = self.key_pattern%key
         if type(value) is not array:
-            value = pack(self.type*len(value),*value)
+            value = pack(self.type*len(value), *value)
         else:
             value = value.tostring()
         return mc.set(key, value, expire)
 
     def get_list(self, args_list):
-        key_pattern = self.key_pattern
-        key_list = [key_pattern%i for i in args_list]
-        result = []
-        for i in mc.get_list(key_list):
-            if i is None:
-                result.append(i)
-            else:
-                result.append(array(self.type).fromstring(i))
-        return result
+        if args_list:
+            key_pattern = self.key_pattern
+            key_list = [key_pattern%i for i in args_list]
+            result = []
+            for i in mc.get_list(key_list):
+                if i is None:
+                    result.append(i)
+                else:
+                    result.append(array(self.type).fromstring(i))
+            return result
+        else:
+            return []
 
     __call__ = _mc_decorator
     get_multi = _mc_get_multi
     delete = _mc_delete
+
+
+class McLimitA(object):
+    McCls = McCacheA
+    def __init__(self, key_pattern, limit):
+        self.mc = self.McCls(key_pattern)
+        self.limit = limit
+        self.key_pattern = key_pattern
+
+    def __call__(self, key, expire=0):
+        if type(key) is str:
+            _key = key
+            key = lambda x:_key.format(**x)
+
+        def _func(func):
+            arg_names, varargs, varkw, defaults = inspect.getargspec(func)
+
+            if varargs or varkw:
+                raise Exception("do not support varargs")
+
+            defaults = defaults or {}
+            if defaults:
+                args = dict(zip(arg_names[-len(defaults):], defaults))
+            else:
+                args = {}
+
+
+            def _(f, *a, **kw):
+                aa = args.copy()
+                aa.update(zip(arg_names, a))
+                aa.update(kw)
+                mc_key = key(aa)
+                offset = aa.get('offset', 0)
+                limit = aa.get('limit')
+                if limit is None or offset+limit > self.limit:
+                    return func(*a, **kw)
+                smc = self.mc
+                r = smc.get(mc_key)
+                #print  mc_key,r
+                if r is None:
+                    aa['offset'] = 0
+                    aa['limit'] = self.limit
+                    r = f(**aa)
+                    smc.set(mc_key, r, expire)
+                return r[offset:limit+offset]
+            return decorator(_, func)
+        return _func
+
+
+    def delete(self, *args):
+        return self.mc.delete(*args)
+
+
+class McLimit(McLimitA):
+    McCls = McCache
+
+class McLimitM(McLimitA):
+    McCls = McCacheM
+
+
+
