@@ -4,6 +4,15 @@ import sys
 def escape(string):
     return '`%s`' % string
 
+def conditions_null(kwargs, sql_conditions_str):
+    kwds = {}
+    for k, v in kwargs.iteritems():
+        if v is None:
+            sql_conditions_str.append("%s is NULL"%escape(k))
+        else:
+            kwds[k] = v
+    return kwds
+
 class Query(object):
     '''
     Gives quick access to database by setting attributes (query conditions, et
@@ -76,13 +85,15 @@ class Query(object):
     def __init__(self, query_type='SELECT *', args=(), conditions={}, model=None, db=None):
         #from sqlbean.model import Model
         self.type = query_type
-        self.conditions = conditions
         if args:
             self.sql_conditions_str = [args[0]]
             self.sql_conditions_para = list(args[1:])
         else:
             self.sql_conditions_str = []
             self.sql_conditions_para = []
+
+        self.conditions = conditions_null(conditions, self.sql_conditions_str)
+
         self.order = ''
         self.limit = ()
         self.cache = None
@@ -148,11 +159,15 @@ class Query(object):
 
         return result
 
+
+
     def where(self, *args, **kwargs):
         if args:
             self.sql_conditions_str.append(args[0])
             self.sql_conditions_para.extend(args[1:])
-        self.conditions.update(kwargs)
+        kwds = conditions_null(kwargs, self.sql_conditions_str)
+        self.conditions.update(kwds)
+
         return self
 
     def order_by(self, field):
@@ -260,7 +275,7 @@ class Query(object):
         try:
             if values:
                 cursor.execute(sql, values)
-            else: 
+            else:
                 cursor.execute(sql)
             if db.b_commit:
                 cls.commit(db)
@@ -270,6 +285,8 @@ class Query(object):
             print "raw_sql: exception: ", ex
             sys.stdout.flush()
             raise
+        #print "sql:", sql
+        #print "values:", values
         return cursor
 
     @classmethod
