@@ -2,7 +2,7 @@
 from sqlbean.db.query import Query, escape
 from sqlbean.db.mc_connection import mc
 from marshal import dumps, loads
-from sqlbean.metamodel import cache, lower_name, ModelBase, get_or_create, save, get, __eq__
+from sqlbean.metamodel import cache, lower_name, ModelBase, get_or_create, save, get, __eq__, __nq__
 from array import array
 from datetime import datetime
 
@@ -29,6 +29,8 @@ class McModel(object):
     debug = False
     get_or_create = get_or_create
     __eq__ = __eq__
+    __nq__ = __nq__
+
     def __init__(self, *args, **kwargs):
         'Allows setting of fields using kwargs'
         self.__dict__[self.Meta.pk] = None
