@@ -1,6 +1,8 @@
 from sqlbean.db.query import escape, Query
 from sqlbean.db.connection import get_db_by_table
 
+def __ne__(self, other):
+    return not (self == other)
 
 def __eq__(self, other):
     if other is not None:
