@@ -1,6 +1,6 @@
 #coding:utf-8
 from sqlbean.db.query import Query, escape
-from sqlbean.metamodel import cache, lower_name, ModelBase, get_or_create, save, get , __eq__
+from sqlbean.metamodel import cache, lower_name, ModelBase, get_or_create, save, get , __eq__, __nq__
 
 class Model(object):
     '''
@@ -73,6 +73,7 @@ class Model(object):
     '''
     __metaclass__ = ModelBase
     __eq__ = __eq__
+    __nq__ = __nq__
     debug = False
 
     def __init__(self, *args, **kwargs):
